diff --git a/modules/demux/live555.cpp b/modules/demux/live555.cpp
index cd77304..5c446a1 100644
--- a/modules/demux/live555.cpp
+++ b/modules/demux/live555.cpp
@@ -27,6 +27,8 @@
  * Preamble
  *****************************************************************************/
 
+// FIXME: Remember to add new LIVEMEDIA_LIBRARY_VERSION_INT check
+
 /* For inttypes.h
  * Note: config.h may include inttypes.h, so make sure we define this option
  * early enough. */
@@ -134,7 +136,6 @@ vlc_module_end();
 /*****************************************************************************
  * Local prototypes
  *****************************************************************************/
-
 typedef struct
 {
     demux_t         *p_demux;
@@ -153,9 +154,7 @@ typedef struct
 
     bool            b_rtcp_sync;
     char            waiting;
-    int64_t         i_pts;
-    u_int32_t       i_start_seq;
-
+    int64_t         i_npt;
 } live_track_t;
 
 struct timeout_thread_t
@@ -163,7 +162,7 @@ struct timeout_thread_t
     VLC_COMMON_MEMBERS
 
     int64_t      i_remain;
-    bool   b_handle_keep_alive;
+    bool         b_handle_keep_alive;
     demux_sys_t  *p_sys;
 };
 
@@ -185,22 +184,23 @@ struct demux_sys_t
     /* Weird formats */
     asf_header_t     asfh;
     stream_t         *p_out_asf;
-    bool       b_real;
+    bool             b_real;
 
     /* */
-    int64_t          i_pcr; /* The clock */
-    int64_t          i_npt_length;
-    int64_t          i_npt_start;
+    int64_t          i_pcr;        /* The clock */
+    int64_t          i_npt;        /* current normal play time in microseconds */
+    int64_t          i_npt_length; /* streamlength in microseconds */
+    int64_t          i_npt_start;  /* last starting point in microseconds */
 
     /* timeout thread information */
     int              i_timeout;     /* session timeout value in seconds */
-    bool       b_timeout_call;/* mark to send an RTSP call to prevent server timeout */
+    bool             b_timeout_call;/* mark to send an RTSP call to prevent server timeout */
     timeout_thread_t *p_timeout;    /* the actual thread that makes sure we don't timeout */
 
     /* */
     bool             b_force_mcast;
     bool             b_multicast;   /* if one of the tracks is multicasted */
-    bool             b_no_data;     /* if we never received any data */
+    bool             b_no_data;     /* if we never received any data from the start */
     int              i_no_data_ti;  /* consecutive number of TaskInterrupt */
 
     char             event;
@@ -270,8 +270,9 @@ static int  Open ( vlc_object_t *p_this )
     p_sys->i_track = 0;
     p_sys->track   = NULL;
     p_sys->i_pcr = 0;
-    p_sys->i_npt_start = 0;
-    p_sys->i_npt_length = 0;
+    p_sys->i_npt = -1;
+    p_sys->i_npt_start = -1;
+    p_sys->i_npt_length = -1;
     p_sys->p_out_asf = NULL;
     p_sys->b_no_data = true;
     p_sys->i_no_data_ti = 0;
@@ -353,7 +354,7 @@ static int  Open ( vlc_object_t *p_this )
         /* sdp:// link from SAP */
         p_sys->p_sdp = strdup( p_sys->psz_path );
     }
-    else if( ( i_return = Connect( p_demux ) ) != VLC_SUCCESS )
+    else if( ( i_return = Connect( p_demux ) ) != VLC_SUCCESS ) /* rtsp:// link */
     {
         msg_Err( p_demux, "Failed to connect with rtsp://%s", p_sys->psz_path );
         goto error;
@@ -479,7 +480,7 @@ static int Connect( demux_t *p_demux )
     char *p_sdp       = NULL;
     int  i_http_port  = 0;
     int  i_ret        = VLC_SUCCESS;
-    int i_lefttries;
+    int  i_lefttries  = 3;
 
     if( p_sys->url.i_port == 0 ) p_sys->url.i_port = 554;
     if( p_sys->url.psz_username || p_sys->url.psz_password )
@@ -502,7 +503,6 @@ static int Connect( demux_t *p_demux )
         psz_pwd  = var_CreateGetString( p_demux, "rtsp-pwd" );
     }
 
-    i_lefttries = 3;
 createnew:
     i_lefttries--;
     if( !vlc_object_alive (p_demux) || p_demux->b_error )
@@ -537,9 +537,7 @@ createnew:
      */
     if( var_CreateGetBool( p_demux, "rtsp-kasenna" ))
     {
-#if LIVEMEDIA_LIBRARY_VERSION_INT > 1130457500
         p_sys->rtsp->setUserAgentString( "VLC_MEDIA_PLAYER_KA" );
-#endif
     }
 
 describe:
@@ -642,7 +640,7 @@ static int SessionsSetup( demux_t *p_demux )
     MediaSubsessionIterator *iter   = NULL;
     MediaSubsession         *sub    = NULL;
 
-    bool     b_rtsp_tcp = false;
+    bool           b_rtsp_tcp = false;
     int            i_client_port;
     int            i_return = VLC_SUCCESS;
     unsigned int   i_buffer = 0;
@@ -723,21 +721,17 @@ static int SessionsSetup( demux_t *p_demux )
             /* Issue the SETUP */
             if( p_sys->rtsp )
             {
-                bool tcp = b_rtsp_tcp;
-                bool mcast = p_sys->b_force_mcast;
                 if( !p_sys->rtsp->setupMediaSubsession( *sub, False,
-                                           tcp ? True : False,
-                                           ( mcast && !tcp ) ? True : False ) )
+                                           b_rtsp_tcp, p_sys->b_force_mcast ) )
                 {
-                    tcp = !tcp;
                     /* if we get an unsupported transport error, toggle TCP use and try again */
                     if( !strstr(p_sys->env->getResultMsg(), "461 Unsupported Transport")
                      || !p_sys->rtsp->setupMediaSubsession( *sub, False,
-                                           tcp ? False : True,
-                                           ( mcast && !tcp ) ? True : False ) )
+                                           !b_rtsp_tcp, false ) )
                     {
                         msg_Err( p_demux, "SETUP of'%s/%s' failed %s", sub->mediumName(),
                                  sub->codecName(), p_sys->env->getResultMsg() );
+                        /* Skipt this track. Nothing to free yet, but beware when you make changes */
                         continue;
                     }
                 }
@@ -766,7 +760,7 @@ static int SessionsSetup( demux_t *p_demux )
             tk->p_out_muxed = NULL;
             tk->waiting     = 0;
             tk->b_rtcp_sync = false;
-            tk->i_pts       = 0;
+            tk->i_npt       = 0;
             tk->i_buffer    = 65536;
             tk->p_buffer    = (uint8_t *)malloc( 65536 );
             if( !tk->p_buffer )
@@ -1005,21 +999,14 @@ static int SessionsSetup( demux_t *p_demux )
     delete iter;
     if( p_sys->i_track <= 0 ) i_return = VLC_EGENERIC;
 
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1199404800)
     /* Retrieve the starttime if possible */
     p_sys->i_npt_start = (int64_t)( p_sys->ms->playStartTime() * (double)1000000.0 );
-#else
-    p_sys->i_npt_start = (int64_t) -1;
-#endif
     if( p_sys->i_npt_start < 0 )
         p_sys->i_npt_start = -1;
+    else p_sys->i_npt = p_sys->i_npt_start;
 
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1199404800)
     /* Retrieve the duration if possible */
     p_sys->i_npt_length = (int64_t)( p_sys->ms->playEndTime() * (double)1000000.0 );
-#else
-    p_sys->i_npt_length = (int64_t) -1;
-#endif
     if( p_sys->i_npt_length < 0 )
         p_sys->i_npt_length = -1;
 
@@ -1069,31 +1056,14 @@ static int Play( demux_t *p_demux )
     }
     p_sys->i_pcr = 0;
 
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1195257600)
-    for( i = 0; i < p_sys->i_track; i++ )
-    {
-        if( !p_sys->track[i]->b_rtcp_sync )
-            p_sys->track[i]->i_pts = (int64_t) ( p_sys->track[i]->sub->rtpInfo.timestamp * (double)1000000.0 );
-        p_sys->track[i]->i_start_seq = (int)p_sys->track[i]->sub->rtpInfo.seqNum;
-        msg_Info( p_demux, "set startseq: %u", p_sys->track[i]->i_start_seq );
-    }
-#endif
-
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1199404800)
     /* Retrieve the starttime if possible */
     p_sys->i_npt_start = (int64_t)( p_sys->ms->playStartTime() * (double)1000000.0 );
-#else
-    p_sys->i_npt_start = -1;
-#endif
     if( p_sys->i_npt_start < 0 )
         p_sys->i_npt_start = -1;
+    else p_sys->i_npt = p_sys->i_npt_start;
 
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1199404800)
     /* Retrieve the duration if possible */
     p_sys->i_npt_length = (int64_t)( p_sys->ms->playEndTime() * (double)1000000.0 );
-#else
-    p_sys->i_npt_length = -1;
-#endif
     if( p_sys->i_npt_length < 0 )
         p_sys->i_npt_length = -1;
 
@@ -1110,8 +1080,7 @@ static int Demux( demux_t *p_demux )
     demux_sys_t    *p_sys = p_demux->p_sys;
     TaskToken      task;
 
-    bool      b_send_pcr = true;
-    int64_t         i_pcr = 0;
+    bool            b_send_pcr = true;
     int             i;
 
     /* Check if we need to send the server a Keep-A-Live signal */
@@ -1122,28 +1091,16 @@ static int Demux( demux_t *p_demux )
         p_sys->b_timeout_call = false;
     }
 
-
     for( i = 0; i < p_sys->i_track; i++ )
     {
         live_track_t *tk = p_sys->track[i];
 
         if( tk->b_asf || tk->b_muxed )
             b_send_pcr = false;
-#if 0
-        if( i_pcr == 0 )
-        {
-            i_pcr = tk->i_pts;
-        }
-        else if( tk->i_pts != 0 && i_pcr > tk->i_pts )
-        {
-            i_pcr = tk->i_pts ;
-        }
-#endif
     }
-    if( p_sys->i_pcr > 0 )
+    if( p_sys->i_pcr > 0 && b_send_pcr )
     {
-        if( b_send_pcr )
-            es_out_Control( p_demux->out, ES_OUT_SET_PCR, p_sys->i_pcr );
+        es_out_Control( p_demux->out, ES_OUT_SET_PCR, p_sys->i_pcr );
     }
 
     /* First warn we want to read data */
@@ -1181,19 +1138,18 @@ static int Demux( demux_t *p_demux )
             es_out_Control( p_demux->out, ES_OUT_RESET_PCR );
             tk->b_rtcp_sync = true;
             /* reset PCR */
-            tk->i_pts = 0;
+            tk->i_npt = 0;
             p_sys->i_pcr = 0;
-            i_pcr = 0;
+            p_sys->i_npt = 0;
         }
     }
 
     if( p_sys->b_multicast && p_sys->b_no_data &&
         ( p_sys->i_no_data_ti > 120 ) )
     {
-        /* FIXME Make this configurable
+        /* FIXME Make this configurable 
         msg_Err( p_demux, "no multicast data received in 36s, aborting" );
-        return 0;
-        */
+        return 0; */
     }
     else if( !p_sys->b_multicast && p_sys->b_no_data &&
              ( p_sys->i_no_data_ti > 34 ) )
@@ -1203,15 +1159,16 @@ static int Demux( demux_t *p_demux )
 
         if( !b_rtsp_tcp && p_sys->rtsp && p_sys->ms )
         {
-            msg_Warn( p_demux, "no data received in 10s. Switching to TCP" );
+            msg_Warn( p_demux, "no UDP data received in 10s. Switching to TCP" );
             if( RollOverTcp( p_demux ) )
             {
                 msg_Err( p_demux, "TCP rollover failed, aborting" );
                 return 0;
             }
+        } else if( p_sys->i_no_data_ti > 34 ) {
+            msg_Err( p_demux, "no TCP data received in 10s, aborting" );
+            return 0;
         }
-        msg_Err( p_demux, "no data received in 10s, aborting" );
-        return 0;
     }
     else if( !p_sys->b_multicast && p_sys->i_no_data_ti > 34 )
     {
@@ -1228,7 +1185,7 @@ static int Demux( demux_t *p_demux )
 static int Control( demux_t *p_demux, int i_query, va_list args )
 {
     demux_sys_t *p_sys = p_demux->p_sys;
-    int64_t *pi64;
+    int64_t *pi64, i64;
     double  *pf, f;
     bool *pb, *pb2, b_bool;
     int *pi_int;
@@ -1236,6 +1193,42 @@ static int Control( demux_t *p_demux, int i_query, va_list args )
     switch( i_query )
     {
         case DEMUX_GET_TIME:
+            pi64 = (int64_t*)va_arg( args, int64_t * );
+            if( p_sys->i_npt > 0 )
+            {
+                *pi64 = p_sys->i_npt;
+                return VLC_SUCCESS;
+            }
+            return VLC_EGENERIC;
+
+        case DEMUX_SET_TIME:
+            i64 = (int64_t)va_arg( args, int64_t );
+            if( p_sys->i_npt > 0 && p_sys->i_npt_length > 0 )
+            {
+                float time = (float)((double)i64 / (double)1000000.0); /* in second */
+                if( !p_sys->rtsp->playMediaSession( *p_sys->ms, time, -1, 1 ) )
+                {
+                    msg_Err( p_demux, "PLAY failed %s",
+                        p_sys->env->getResultMsg() );
+                    return VLC_EGENERIC;
+                }
+                es_out_Control( p_demux->out, ES_OUT_RESET_PCR );
+                p_sys->i_pcr = 0;
+
+                /* Retrieve the starttime if possible */
+                p_sys->i_npt_start = (int64_t)( p_sys->ms->playStartTime() * (double)1000000.0 );
+                if( p_sys->i_npt_start < 0 )
+                    p_sys->i_npt_start = -1;
+                else p_sys->i_npt = p_sys->i_npt_start;
+
+                /* Retrieve the duration if possible */
+                p_sys->i_npt_length = (int64_t)( p_sys->ms->playEndTime() * (double)1000000.0 );
+                if( p_sys->i_npt_length < 0 )
+                    p_sys->i_npt_length = -1;
+
+                msg_Dbg( p_demux, "time seek start: %lld stop:%lld", p_sys->i_npt_start, p_sys->i_npt_length );
+                return VLC_SUCCESS;
+            }
             return VLC_EGENERIC;
 
         case DEMUX_GET_LENGTH:
@@ -1248,6 +1241,12 @@ static int Control( demux_t *p_demux, int i_query, va_list args )
             return VLC_EGENERIC;
 
         case DEMUX_GET_POSITION:
+            pf = (double*)va_arg( args, double* );
+            if( p_sys->i_npt_length > 0 && p_sys->i_npt > 0)
+            {
+                *pf = ( (double)p_sys->i_npt / (double)p_sys->i_npt_length );
+                return VLC_SUCCESS;
+            }
             return VLC_EGENERIC;
 
         case DEMUX_SET_POSITION:
@@ -1267,36 +1266,19 @@ static int Control( demux_t *p_demux, int i_query, va_list args )
                 }
                 es_out_Control( p_demux->out, ES_OUT_RESET_PCR );
                 p_sys->i_pcr = 0;
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1195257600)
-                /* Retrieve RTP-Info values */
-                for( i = 0; i < p_sys->i_track; i++ )
-                {
-                    //if( !p_sys->track[i]->b_rtcp_sync )
-                    p_sys->track[i]->b_rtcp_sync = false;
-                    p_sys->track[i]->i_pts = (int64_t) ( p_sys->track[i]->sub->rtpInfo.timestamp * (double)1000000.0 );
-                    p_sys->track[i]->i_start_seq = p_sys->track[i]->sub->rtpInfo.seqNum;
-                    msg_Info( p_demux, "set pos startseq: %u", p_sys->track[i]->i_start_seq );
-                }
-#endif
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1199404800)
+
                 /* Retrieve the starttime if possible */
                 p_sys->i_npt_start = (int64_t)( p_sys->ms->playStartTime() * (double)1000000.0 );
-#else
-                p_sys->i_npt_start = -1;
-#endif
                 if( p_sys->i_npt_start < 0 )
                     p_sys->i_npt_start = -1;
+                else p_sys->i_npt = p_sys->i_npt_start;
 
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1199404800)
                 /* Retrieve the duration if possible */
                 p_sys->i_npt_length = (int64_t)( p_sys->ms->playEndTime() * (double)1000000.0 );
-#else
-                p_sys->i_npt_length = -1;
-#endif
                 if( p_sys->i_npt_length < 0 )
                     p_sys->i_npt_length = -1;
 
-                msg_Dbg( p_demux, "seek start: %lld stop:%lld", p_sys->i_npt_start, p_sys->i_npt_length );
+                msg_Dbg( p_demux, "position seek start: %lld stop:%lld", p_sys->i_npt_start, p_sys->i_npt_length );
                 return VLC_SUCCESS;
             }
             return VLC_EGENERIC;
@@ -1404,30 +1386,14 @@ static int Control( demux_t *p_demux, int i_query, va_list args )
 
             es_out_Control( p_demux->out, ES_OUT_RESET_PCR );
             p_sys->i_pcr = 0;
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1195257600)
-            for( i = 0; i < p_sys->i_track; i++ )
-            {
-                if( !p_sys->track[i]->b_rtcp_sync )
-                    p_sys->track[i]->i_pts = 0; // (int64_t) ( p_sys->track[i]->sub->rtpInfo.timestamp * (double)1000000.0 );
-                p_sys->track[i]->i_start_seq = p_sys->track[i]->sub->rtpInfo.seqNum;
-                msg_Info( p_demux, "set pause startseq: %u", p_sys->track[i]->i_start_seq );
-            }
-#endif
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1199404800)
+
             /* Retrieve the starttime if possible */
             p_sys->i_npt_start = (int64_t)( p_sys->ms->playStartTime() * (double)1000000.0 );
-#else
-            p_sys->i_npt_start = -1;
-#endif
             if( p_sys->i_npt_start < 0 )
                 p_sys->i_npt_start = -1;
 
-#if (LIVEMEDIA_LIBRARY_VERSION_INT >= 1199404800)
             /* Retrieve the duration if possible */
             p_sys->i_npt_length = (int64_t)( p_sys->ms->playEndTime() * (double)1000000.0 );
-#else
-            p_sys->i_npt_length = -1;
-#endif
             if( p_sys->i_npt_length < 0 )
                 p_sys->i_npt_length = -1;
 
@@ -1467,6 +1433,7 @@ static int RollOverTcp( demux_t *p_demux )
         live_track_t *tk = p_sys->track[i];
 
         if( tk->b_muxed ) stream_DemuxDelete( tk->p_out_muxed );
+        if( tk->p_es ) es_out_Del( p_demux->out, tk->p_es );
         es_format_Clean( &tk->fmt );
         free( tk->p_buffer );
         free( tk );
@@ -1484,8 +1451,7 @@ static int RollOverTcp( demux_t *p_demux )
     p_sys->i_track = 0;
 
     /* Reopen rtsp client */
-    if( ( p_demux->s != NULL ) &&
-        ( i_return = Connect( p_demux ) ) != VLC_SUCCESS )
+    if( ( i_return = Connect( p_demux ) ) != VLC_SUCCESS )
     {
         msg_Err( p_demux, "Failed to connect with rtsp://%s",
                  p_sys->psz_path );
@@ -1526,13 +1492,14 @@ static void StreamRead( void *p_private, unsigned int i_size,
     demux_sys_t    *p_sys = p_demux->p_sys;
     block_t        *p_block;
 
-    //msg_Dbg( p_demux, "pts: %d", pts.tv_sec );
-
-    int64_t i_pts = (uint64_t)pts.tv_sec * UINT64_C(1000000) +
-        (uint64_t)pts.tv_usec;
+    int64_t i_pts = (int64_t)pts.tv_sec * INT64_C(1000000) +
+        (int64_t)pts.tv_usec;
 
     /* XXX Beurk beurk beurk Avoid having negative value XXX */
-    i_pts &= UINT64_C(0x00ffffffffffffff);
+    i_pts &= INT64_C(0x00ffffffffffffff);
+    
+    /* Retrieve NPT for this pts */
+    tk->i_npt = (int64_t) INT64_C(1000000) * tk->sub->getNormalPlayTime(pts);
 
     if( tk->b_quicktime && tk->p_es == NULL )
     {
@@ -1593,12 +1560,6 @@ static void StreamRead( void *p_private, unsigned int i_size,
         tk->p_es = es_out_Add( p_demux->out, &tk->fmt );
     }
 
-#if 0
-    fprintf( stderr, "StreamRead size=%d pts=%lld\n",
-             i_size,
-             pts.tv_sec * 1000000LL + pts.tv_usec );
-#endif
-
     /* grow buffer if it looks like buffer is too small, but don't eat
      * up all the memory on strange streams */
     if( i_truncated_bytes > 0 && tk->i_buffer < 2000000 )
@@ -1633,13 +1594,8 @@ static void StreamRead( void *p_private, unsigned int i_size,
     }
     else if( tk->fmt.i_codec == VLC_FOURCC('H','2','6','1') )
     {
-#if LIVEMEDIA_LIBRARY_VERSION_INT >= 1081468800
         H261VideoRTPSource *h261Source = (H261VideoRTPSource*)tk->sub->rtpSource();
         uint32_t header = h261Source->lastSpecialHeader();
-#else
-        uint32_t header = 0;
-        msg_Warn( p_demux, "need livemedia library >= \"2004.04.09\"" );
-#endif
         p_block = block_New( p_demux, i_size + 4 );
         memcpy( p_block->p_buffer, &header, 4 );
         memcpy( p_block->p_buffer + 4, tk->p_buffer, i_size );
@@ -1673,21 +1629,29 @@ static void StreamRead( void *p_private, unsigned int i_size,
         memcpy( p_block->p_buffer, tk->p_buffer, i_size );
     }
 
-    if( p_sys->i_pcr < i_pts )
+    /* Keep track of PCR */
+    if( tk->fmt.i_cat == VIDEO_ES && (p_sys->i_pcr < i_pts) && (i_pts > 0) && (p_sys->i_pcr > 0) )
     {
+        /* Sync on the video track if it is available (per advise of RFC) */
         p_sys->i_pcr = i_pts;
     }
-
-    if( (i_pts != tk->i_pts) && (!tk->b_muxed) )
+    else if( p_sys->i_pcr < i_pts )
     {
-        p_block->i_pts = i_pts;
+        p_sys->i_pcr = i_pts;
     }
+
+    /* Set pts/dts on the datablocks */
     if( !tk->b_muxed )
     {
+        p_block->i_pts = i_pts;
         /*FIXME: for h264 you should check that packetization-mode=1 in sdp-file */
-        p_block->i_dts = ( tk->fmt.i_codec == VLC_FOURCC( 'm', 'p', 'g', 'v' ) ) ? 0 : i_pts;
+        p_block->i_dts = ( tk->fmt.i_codec == VLC_FOURCC( 'm', 'p', 'g', 'v' ) ) ? 0 : p_block->i_pts;
     }
-
+    
+    /* Update our global npt value */
+    if( tk->i_npt > 0 && tk->i_npt > p_sys->i_npt && tk->i_npt < p_sys->i_npt_length)
+        p_sys->i_npt = tk->i_npt; 
+    
     if( tk->b_muxed )
     {
         stream_DemuxSend( tk->p_out_muxed, p_block );
@@ -1708,11 +1672,6 @@ static void StreamRead( void *p_private, unsigned int i_size,
     tk->waiting = 0;
     p_demux->p_sys->b_no_data = false;
     p_demux->p_sys->i_no_data_ti = 0;
-
-    if( i_pts > 0 && !tk->b_muxed )
-    {
-        tk->i_pts = i_pts;
-    }
 }
 
 /*****************************************************************************
@@ -1766,9 +1725,7 @@ static void TimeoutPrevention( timeout_thread_t *p_timeout )
             msg_Dbg( p_timeout, "reset the timeout timer" );
             if( p_timeout->b_handle_keep_alive == true )
             {
-#if LIVEMEDIA_LIBRARY_VERSION_INT >= 1138089600
                 p_timeout->p_sys->rtsp->getMediaSessionParameter( *p_timeout->p_sys->ms, NULL, psz_bye );
-#endif
                 p_timeout->p_sys->b_timeout_call = false;
             }
             else
